#import <Foundation/Foundation.h>
#import <CDCSdk/CDCSdk.h>

#define PROLIFIC_VID 0x67b

int main(int argc, const char * argv[]) {
    @autoreleasepool {
        cdc_device *list = NULL;
        int32_t ret = cdc_get_device_list_vid(PROLIFIC_VID, &list);
        if (ret <= 0) {
            printf("Device not found, status:%d\n", ret);
            return 0;
        }
        
        printf("[USB info]\n");
        for (int i = 0; i < ret; i++) {
            cdc_device *device = list[i];
            struct cdc_usb_info usbInfo;
            memset(&usbInfo, 0, sizeof(struct cdc_usb_info));
            int32_t usbInfoRet = cdc_get_usb_info(device, &usbInfo);
            if (usbInfoRet == ERROR_SUCCESS) {
                printf("vendor:0x%x\n", usbInfo.vendor);
                printf("product:0x%x\n", usbInfo.product);
                printf("productString:%s\n", usbInfo.productString);
                printf("bcdDevice:0x%x\n", usbInfo.bcdDevice);
                printf("locationID:0x%x\n", usbInfo.locationID);
            }
        }
        
        printf("[GPIO Input][Read GPIO][CH0][PORT NUMBER 0 - 10]\n");
        cdc_device *device = list[0];
        for (int portNumber = GPIO_PORT_NUMBER_0; portNumber <= GPIO_PORT_NUMBER_10; portNumber++) {
            uint8_t result = 0;
            
            int32_t gpioRet = cdc_set_gpio_dir(device, CHANNEL_SELECT_CH0, portNumber, GPIO_DIR_INPUT);
            if (gpioRet != ERROR_SUCCESS) {
                printf("[GPIO Input] Set GPIO dir fail, status:%d\n", gpioRet);
                continue;
            }
            gpioRet = cdc_read_gpio(device, CHANNEL_SELECT_CH0, portNumber, &result);
            printf("GPIO port number %d, ", portNumber);
            if (gpioRet == ERROR_SUCCESS) {
                printf("result:%d", result);
            } else {
                printf("status:%d", gpioRet);
            }
            printf("\n");
        }
        
        printf("[GPIO Output][Write GPIO][CH0][PORT NUMBER 8]\n");
        int32_t gpioRet = cdc_set_gpio_dir(device, CHANNEL_SELECT_CH0, GPIO_PORT_NUMBER_8, GPIO_DIR_OUTPUT);
        if (gpioRet != ERROR_SUCCESS) {
            printf("[GPIO Output] Set GPIO dir fail, status:%d\n", gpioRet);
        } else {
            gpioRet = cdc_write_gpio(device, CHANNEL_SELECT_CH0, GPIO_PORT_NUMBER_8, GPIO_VALUE_LOW);
            if (gpioRet != ERROR_SUCCESS) {
                printf("Write GPIO fail, status:%d\n", gpioRet);
            }
        }
        
        cdc_free_device_list(list);
    }
    return 0;
}
